#
# spec file for package python-postorius
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without testsuite

# keep in sync with setup.py
%global django_mailman3_min_version 1.3.10
%global django_min_version 3.2
%global django_max_version 4.3
%global mailmanclient_min_version 3.3.3

%global webapps_dir /srv/www/webapps

%global postorius_pkgname   postorius

%global postorius_basedir   %{webapps_dir}/mailman/postorius
%global postorius_localedir %{postorius_basedir}/locale
%global postorius_staticdir %{postorius_basedir}/static

%global postorius_etcdir    %{_sysconfdir}/postorius
%global postorius_libdir    %{_localstatedir}/lib/postorius
%global postorius_logdir    %{_localstatedir}/log/postorius
%global postorius_datadir   %{postorius_libdir}/data

# keep in sync with python-HyperKitty/python-mailman-web
# Always only build one flavor: primary python for TW, python311 from the SLE15 python module for 15.x
%if 0%{?suse_version} >= 1550
%define pythons python3
%else
%{?sle15_python_module_pythons}
%endif
%global mypython %pythons
%global mypython_sitelib %{expand:%%{%{mypython}_sitelib}}
%global __mypython %{expand:%%{__%{mypython}}}

Name:           python-postorius
Version:        1.3.10
Release:        3.2
Summary:        A web user interface for GNU Mailman
License:        GPL-3.0-only
URL:            https://gitlab.com/mailman/postorius
#
Source0:        https://gitlab.com/mailman/postorius/-/releases/v%{version}/downloads/postorius-%{version}.tar.gz
Source1:        https://gitlab.com/mailman/postorius/-/releases/v%{version}/downloads/postorius-%{version}.tar.gz.asc
Source2:        python-postorius.keyring
Source3:        python-postorius-rpmlintrc
#
Source10:       postorius-manage.sh
Source12:       postorius.uwsgi
#
Source20:       README.SUSE.md
#
Patch0:         postorius-settings.patch
#
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  acl
BuildRequires:  fdupes
BuildRequires:  openssl
BuildRequires:  python-rpm-macros
BuildRequires:  rsync
BuildRequires:  sudo
BuildArch:      noarch
%if 0%{?suse_version} >= 1550
# use the real python3 primary for rpm pythondistdeps.py
BuildRequires:  python3-packaging
%endif
# SECTION test requirements
BuildRequires:  mailman3 >= 3.3.5
BuildRequires:  %{python_module Django >= %{django_min_version}}
BuildRequires:  %{python_module beautifulsoup4}
BuildRequires:  %{python_module cmarkgfm}
BuildRequires:  %{python_module django-debug-toolbar >= 2.2}
BuildRequires:  %{python_module django-mailman3 >= %{django_mailman3_min_version}}
BuildRequires:  %{python_module django-requests-debug-toolbar >= 0.0.3}
BuildRequires:  %{python_module isort}
BuildRequires:  %{python_module mailmanclient >= %{mailmanclient_min_version}}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module readme_renderer}
BuildRequires:  %{python_module vcrpy}
# /SECTION
%python_subpackages

%description
A web user interface for GNU Mailman

%package -n %{postorius_pkgname}
Summary:        A web user interface for GNU Mailman
Requires:       %{mypython}-django-debug-toolbar >= 2.2.0
Requires:       %{mypython}-django-mailman3 >= %{django_mailman3_min_version}
Requires:       %{mypython}-django-requests-debug-toolbar >= 0.0.3
Requires:       %{mypython}-mailmanclient >= %{mailmanclient_min_version}
Requires:       %{mypython}-readme_renderer
Requires:       (%{mypython}-Django >= %{django_min_version} with %{mypython}-Django < %{django_max_version})
# help in replacing any previously installed flavor package back to the unprefixed package
%if 0%{?suse_version} < 1550
Obsoletes:      python3-%{postorius_pkgname} < %{version}-%{release}
%endif
Provides:       %{mypython}-%{postorius_pkgname} = %{version}-%{release}
Obsoletes:      %{mypython}-%{postorius_pkgname} < %{version}-%{release}

%description  -n %{postorius_pkgname}
A web user interface for GNU Mailman

%package -n %{postorius_pkgname}-web
Summary:        The webroot for GNU Mailman
Requires:       %{postorius_pkgname}
Requires:       acl
Requires:       openssl
Requires:       sudo
Requires:       system-user-%{postorius_pkgname}

%description -n %{postorius_pkgname}-web
A web user interface for GNU Mailman.

This package holds the web interface.

%package -n %{postorius_pkgname}-web-uwsgi
Summary:        Postorius - uwsgi configuration
Requires:       %{postorius_pkgname}-web
%if 0%{suse_version} >= 1550 || 0%{?sle_version} >= 150500
Requires:       %{mypython}-uwsgi-python3
%else
Requires:       uwsgi-python3
%endif

%description -n %{postorius_pkgname}-web-uwsgi
A web user interface for GNU Mailman.

This package holds the uwsgi configuration.

%package -n system-user-%{postorius_pkgname}
Summary:        System user for HyperKitty
BuildArch:      noarch
BuildRequires:  sysuser-tools
%sysusers_requires

%description -n system-user-%{postorius_pkgname}
System user for HyperKitty.

%prep
%setup -q -n postorius-%{version}
cp %{SOURCE20} .
touch settings_local.py

# Copy exmaple_project to just build the static files
rsync -a example_project/* build_static_files

%autopatch -p1

tee > %{postorius_pkgname}.sysuser <<EOF
u %{postorius_pkgname} - "Postorius" %{postorius_basedir} -
EOF

%build
sed -i 's|^#!/usr/bin/env.*|#!%{__mypython}|' \
    example_project/manage.py
sed -i 's|/usr/bin/python3|%{__mypython}|' %{SOURCE10}
sed -i 's|python3|%{mypython}|' %{SOURCE12}

%pyproject_wheel

# Build static files
install -d -m 0755 build_static_files/logs
export PYTHONPATH=$(pwd)/src
%python_exec build_static_files/manage.py collectstatic --clear --noinput

%sysusers_generate_pre %{postorius_pkgname}.sysuser %{postorius_pkgname}

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

install -d -m 0750 \
    %{buildroot}%{postorius_etcdir} \
    %{buildroot}%{postorius_libdir} \
    %{buildroot}%{postorius_datadir} \
    %{buildroot}%{postorius_logdir}

install -d -m 0755 \
    %{buildroot}%{postorius_basedir} \
    %{buildroot}%{postorius_localedir} \
    %{buildroot}%{postorius_staticdir} \

# Copy static files
rsync -a build_static_files/static %{buildroot}%{postorius_basedir}

rsync -a example_project/* %{buildroot}%{postorius_basedir}
chmod -x %{buildroot}%{postorius_basedir}/wsgi.py

rm -f %{buildroot}%{postorius_basedir}/README.rst
rm -f %{buildroot}%{postorius_basedir}/mailman.cfg

# Create an empty settings_local.py. This will be filled with a SECRET_KEY in post
install -m 0644 settings_local.py %{buildroot}%{postorius_etcdir}/settings_local.py

ln -svf %{postorius_etcdir}/settings_local.py \
    %{buildroot}/%{postorius_basedir}/settings_local.py

%fdupes %{buildroot}%{postorius_basedir}

# Manage script
install -d -m 0755 %{buildroot}%{_sbindir}
install -m 0750 %{SOURCE10} %{buildroot}%{_sbindir}/postorius-manage

install -d -m 0755 %{buildroot}%{_sysconfdir}/uwsgi/vassals
install -m 0644 %{SOURCE12} %{buildroot}%{_sysconfdir}/uwsgi/vassals/postorius.ini

install -d -m 0755 %{buildroot}%{_sysusersdir}
install -m 0644 %{postorius_pkgname}.sysuser %{buildroot}%{_sysusersdir}/%{postorius_pkgname}.conf

%if %{with testsuite}
%check
export PYTHONPATH="$(pwd):$(pwd)/src"
export LANG=C.UTF-8
%pytest
# clean flavored alternatives created by test setup, because we are going to install the example_project as docs
rm -rf build/flavorbin
rm -rf build/xdgflavorconfig
%endif

%pre -n %{postorius_pkgname}-web
/usr/sbin/groupadd -r postorius &>/dev/null || :
/usr/sbin/useradd  -g postorius -s /bin/false -r -c "Postorius" -d %{postorius_basedir} postorius &>/dev/null || :

%post -n %{postorius_pkgname}-web
# We need a SECRET_KEY for manage to work
if ! grep -q "^SECRET_KEY.*" %{postorius_etcdir}/settings_local.py; then
    echo "SECRET_KEY='$(openssl rand -base64 48)'" >> %{postorius_etcdir}/settings_local.py
fi
%{_sbindir}/postorius-manage makemigrations --pythonpath /srv/www/webapps/mailman/postorius/ --settings settings
%{_sbindir}/postorius-manage migrate --pythonpath /srv/www/webapps/mailman/postorius/ --settings settings

%pre -n system-user-%{postorius_pkgname} -f %{postorius_pkgname}.pre

%files -n %{postorius_pkgname}
%doc README.rst example_project src/postorius/doc/*.rst
%license COPYING
%{mypython_sitelib}/postorius
%{mypython_sitelib}/postorius-%{version}*-info

%files -n %{postorius_pkgname}-web
%doc README.SUSE.md
%{_sbindir}/postorius-manage
%dir %{webapps_dir}
%dir %{webapps_dir}/mailman

%defattr(-,root,postorius)
%dir %{postorius_basedir}
%{postorius_basedir}/__init__.py
%{postorius_basedir}/manage.py
%{postorius_basedir}/settings.py
%{postorius_basedir}/settings_local.py
%{postorius_basedir}/test_settings.py
%{postorius_basedir}/urls.py
%{postorius_basedir}/wsgi.py

%dir %{postorius_basedir}/static
%{postorius_basedir}/static/admin
%{postorius_basedir}/static/django-mailman3
%{postorius_basedir}/static/postorius
%{postorius_basedir}/static/debug_toolbar

%attr(750,root,postorius) %dir %{postorius_etcdir}
%attr(640,root,postorius) %config(noreplace) %{postorius_etcdir}/settings_local.py
%attr(750,root,postorius) %dir %{postorius_libdir}
%attr(750,postorius,postorius) %dir %{postorius_datadir}
%attr(750,postorius,postorius) %dir %{postorius_logdir}

%files -n %{postorius_pkgname}-web-uwsgi
%dir %{_sysconfdir}/uwsgi
%dir %{_sysconfdir}/uwsgi/vassals
%config (noreplace) %{_sysconfdir}/uwsgi/vassals/postorius.ini

%files -n system-user-%{postorius_pkgname}
%{_sysusersdir}/%{postorius_pkgname}.conf

%changelog
* Thu Mar  7 2024 Andreas Schneider <asn@cryptomilk.org>
- Validate source tarball
- Split out system user
* Mon Mar  4 2024 Ben Greiner <code@bnavigator.de>
- Provide postorius name and group in web package (rpm 4.19)
* Thu Feb 29 2024 Ben Greiner <code@bnavigator.de>
- Simplify python flavor selection
  * Go back to primary python3 on Tumbleweed
  * Use SLE15 python module pythons on 15.x
- Build PEP517 wheel
* Mon Nov  6 2023 Marcus Rueckert <mrueckert@suse.de>
- make it easy to run a build without testsuite
  osc build --without=testsuite
* Mon Nov  6 2023 Marcus Rueckert <mrueckert@suse.de>
- make it easier to notice to keep buildrequires and runtime
  requires version limits in sync. This will also help us to notice
  early when the version of other libraries do not match the
  requires encoded in the source code.
* Thu Nov  2 2023 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.3.10
  * See https://gitlab.com/mailman/postorius/-/blob/v1.3.10/src/postorius/doc/news.rst
    or the file news.rst in the postorius package
* Sun Jul  2 2023 Andreas Schneider <asn@cryptomilk.org>
- Fix uwsgi requirement
* Sat Jul  1 2023 Andreas Schneider <asn@cryptomilk.org>
- Use sle15_python_module_pythons
* Fri Jun 30 2023 Andreas Schneider <asn@cryptomilk.org>
- Fix building on Leap
* Sun Jun 25 2023 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.3.8
  * The buttons and confirmation page for removing members have been revised in
    an attempt to reduce accidental removal of all members. (Fixes #545)
  * Add bounce score for members in the Members table (See #12)
  * Add support for Python 3.11.
- Use sle15_python_module_pythons
* Thu Nov 17 2022 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.3.7
  * Fix a bug where various form(s) allowed setting empty values for
    delivery_mode and language. (Fixes #540, #522)
  * Rename labels description and info fields as 'Short Description' and 'Long
    Description' to signify what they mean. (Fixes #510)
  * Use date to format the dates in 'List Metrics' section in the List summary
    page. (Fixes #508)
  * Sort the list of languages in all Select elements alphabetically so they
    are easier to naviate with screen readers. (Fixes #498)
  * Add support for Django 4.0
  * A couple of unit tests are now marked expectedFailure due to
    https://gitlab.com/mailman/mailman/-/merge_requests/997. (See #548)
  * Translate template names in the “New Templates” page (See #547)
  * Translate the section names in the MailingList->"Settings" tab. (See #550)
  * Add support for Django 4.1
  * Add support for Python 3.10
  * Remove support for Django < 3.2
  * Remove support for Python < 3.7
  * Replace the use of mock with unittest.mock
  * Change the way role is selector in the List index page to allow use of the
  * filtering without javascript enabled dropdowns. It also enhances usability
    by enabling the roles that are currently active by default. (See #544)
  * Show the number of files in each Mailman queue under 'System Information'
    tab for Admins. (Fixes #480)
- Removed postorius-fix-django-4.0-compatibility.patch
- Add BR for django debug toolbar
* Wed Jul  6 2022 Andreas Schneider <asn@cryptomilk.org>
- Add missing makemigritions on update
* Wed Jul  6 2022 Ben Greiner <code@bnavigator.de>
- Fix Requires for %%{mypython}-uwsgi-python3 on Tumbleweed vs.
  uwsgi-python3 on 15.x
* Tue Jul  5 2022 Andreas Schneider <asn@cryptomilk.org>
- Fix Requires for uwsgi-python3
* Mon Jul  4 2022 Ben Greiner <code@bnavigator.de>
- Use Python 3.9 like the rest of mailman3
* Thu Jun  9 2022 Andreas Schneider <asn@cryptomilk.org>
- Fix BR for mailman3 (package has been renamed)
* Thu May 26 2022 pgajdos@suse.com
- python-mock is not required for build
* Mon Feb 21 2022 Andreas Schneider <asn@cryptomilk.org>
- Make compatible with django 4.0
  * Added postorius-fix-django-4.0-compatibility.patch
* Thu Nov 18 2021 Matej Cepl <mcepl@suse.com>
- Fix missing minimal requirements on Django.
* Thu Nov 18 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.3.6
  - Security:
  - Check that a user owns the email address they are trying
    to unsubscribe. This fixes a bug in which any logged-in
    user could unsubscribe any email address from any mailing
    list, leaking whether that address was subscribed
    originally. (CVE-2021-40347)
  - UI:
  - Add 'Delivery Mode' and 'Moderation Action' columns to
  - List members page.  Add support to list and handle pending
    un-subscription requests.
  - Add support to specify a reason when handling
    (un)subscription requests
  - Success messages to mass subscribes now properly
    distinguish subscription from invitation and indicate
    possible pending confirmation or approval.
  - User profile dropdown no longer is too far right.
  - Expose archive_rendering_mode in Archiver settings to
    choose between plaintext and rich text rendering of emails
    in Hyperkitty.
  - Allow choosing delivery_mode and delivery_status when
    subscribing to a List.
  - Redirect to domain_index after domain_edit succeeds.
  - Expose new bounce_notify_owner_on_bounce_increment list
    setting on Bounce Processing settings, and expose the
    corresponding template.
  - Expose the forward_unrecognized_bounces_to setting on
    Bounce Processing settings.
  - Clarified the description of Maximum number of recipients.
  - List summary view will now display a table for all
    subscriptions with delivery_mode and delivery_status.
  - Add a new user management interface for superusrs.
  - Allow searching for users in list user views.
  - Show both display name and email in user management
    interface if available,
  - Allow list:admin:notice:pending template to be set in
    Postorius.
  - Other:
  - Use mass-subscription API in core for Mass Removal of
    Members.
  - Fix a bug where users with multiple subscriptions to a List
    couldn't view their Preferences for all addresses.
  - Check for pending unsubscription requests and notify user
    when the request is pending approval.
  - Improve the performance of Members' page by skipping an API
    call.
  - Improve the performance of List index page for Superuser.
  - Skip looking up choosable_domains for non-superuser to
    reduce API calls.
  - Improve the performance of List owner access checks.
  - Add a new APICountingMiddleware to performance testing
    purposes.
  - Use user_id as subscriber instead of addresses to improve
    the efficiency of list index page.
  - AUTOCREATE_MAILMAN_USER setting is now removed and
    a Mailman user is always created when a User object in
    created in Django. Also remove duplicate implementation of
    get_mailman_user from MailmanUserManager so that we can use
    a single implementation that uses caching for efficient
    lookups. Bump bundled jQuery to 3.6.0.slim version.
  - Use the full jQuery not the slim version.
  - Do not show Ownerships and Moderator roles in the
    'Subscriptions' page under mange new user interface.
  - Ascessibility:
  - Move the focus to the textarea in mass subscribe page if
    there are errors in the form.
* Wed Jun  2 2021 Andreas Schneider <asn@cryptomilk.org>
- Remove the postorius-admin user
* Tue May 25 2021 Andreas Schneider <asn@cryptomilk.org>
- Create static files as part of the build process
- Fixed CVE-2021-31997
* Tue May  4 2021 Ben Greiner <code@bnavigator.de>
- restrict to primary python3 flavor due to mailman
* Fri Feb 12 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.3.4
  * Update the default Site when creating a domain to match the domain if it is
    example.com. (Closes #427)
  * Add the ability to subscribe via Primary Address instead of specific
    address. (See !516)
  * Fix a bug where the user's display name would be ignore when
    subscribing. (Closes #429)
  * Display a user's name in the pending subscription request list. (Closes #430)
  * Set a user's preferrred_address in Core if it isn't already set and the user
    has a Primary Address that is verified.
  * Use the new APIs in Core to get the count of held messages and pending
    subscriptions to improve peroformance of settings page for list
    owners. (Fixes #417)
  * Show held message is local time of the User. (Closes #434)
  * Fix a bug where non-member options page would show an owner's options if the
    same email was subscribed as owner and non-member in a list. (Closes #436)
  * Switching subscription from one email address to other or Primary Address now
    preserves preferences and does not require Moderator approval. (Closes #425)
  * Make 'Archives' and 'List Options' urls more prominently visible in the
    list summary page as buttons. (Closes #439)
  * Added the ability to issue invitations from the mass subscribe view.
  * Expose emergency moderation setting for MailingList.
  * Fixed some minor HTML errors. (Closes #442)
  * Fix the bug where ListOfStringsField couldn't be unset in Postorius. (Closes
    [#444])
  * Allow list:user:action:invite template to be set in Postorius. (Closes
    [#454])
  * Fix a bug where the Bans form would always use default language instead of
    current request's language. (Closes #441)
  * Fix the URL on cancel buttons in template's confirm delete page. (Closes
    [#458])
  * Use server side filtering for pending subscription requests for moderator
    approval. (See !559)
  * Allow setting moderation action for a nonmember from Held Message modal. (
    Closes #448)
  * Add a new view to confirm subscriptions or new emails for Users using
    Postorius. (Fixes #459)
  * Fix a bug where membership check compared email addresses in different
    cases. (Closes #457)
  * Mass removal now accepts address formats with display names and/or angle
    brackets. (Closes #455)
  * Add support to override send_welcome_message when mass subscribing to
    suppress welcome messages. (Closes #99)
  * Add support for Django 3.1.x. (See !574)
  * The list's send_goodbye_message is now settable on the Automatic
    Responses view.  (Closes #466)
  * Support HYPERKITTY_ENABLE_GRAVATAR setting to control the user gravatar.
    (Closes #467)
- Fix building on tumbleweed
* Sun Dec 20 2020 Andreas Schneider <asn@cryptomilk.org>
- Improve documentation (README.SUSE.md)
* Sat Dec 12 2020 Andreas Schneider <asn@cryptomilk.org>
- Fix chdir path in uwsgi config
- Update README.SUSE.md
* Sat Oct  3 2020 Andreas Schneider <asn@cryptomilk.org>
- Create a postorius-web package with webroot files
- Create a postorius-web-uwsgi with uwsgi configuration
- Added postorius-settings.patch
  * Sets the FHS default paths
* Tue Aug  4 2020 Stasiek Michalski <stasiek@michalski.cc>
- Update to 1.3.3
  * Expose additional list settings.
  * Correct description of Digest Frequency.
  * Added links to Reply-To munging articles.
  * Fix "Show Headers" button to show the held message headers in the
    held message popup.
  * Fix the held message popup structure and increase the max width of the popup
    to be 800px(modal-lg) for larger screens.
  * Fix FILTER_VHOST = True option to try to find the email host corresponding
    to the requesting web host.
  * Allow specifying a reason when rejecting a held message.
  * Allow users to set their preferred language in their preferences.
  * Add support to ban addresses for the entire Mailman installation.
  * Un-handled HTTPError exception raised from MailmanClient now results in an
    error page and proper logging instead of mysterious KeyError in logs.
  * Change List settings navigation to be vertical instead of horizontal.
  * Move bounce processing settings into a new vertical tab for better
    visibility.
  * Add URL to edit the Web host for each domain in Domain Index page. Also, show
    the SITE_ID for each webhost.
* Tue Apr 14 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.3.2 (no changelog)
* Thu Jan 23 2020 pgajdos@suse.com
- the pytest issue in 15 will be fixed on python rpm macros level
* Fri Jan 17 2020 pgajdos@suse.com
- %%check correctly also for 15
* Mon Dec  2 2019 pgajdos@suse.com
- call spec-cleaner
* Wed Nov 27 2019 pgajdos@suse.com
- package example_project in doc
* Fri Nov 15 2019 pgajdos@suse.com
- initial version 1.3.0 [SLE-7686]
